/**
 * @fileOverview
 * 
 * This JSONP specifies which surveys should be loaded depending on the current URL. 
 * 
 * The JSONP structure is the following:
 * 
 * *   pop_up_settings_file
 * >   URL to the popup settings file, described in *data/custom_invitation_settings.js*
 *
 *     *   white_list
 *     >   Array of regular expressions as strings
 *
 *     *   black_list
 *     >   Array of regular expressions as strings
 *
 * 
 * The expressions in the black list are stronger than the expressions in the white list.
 * 
 */

 SurveyInvitation.load_survey_url_rules_callback({
  "surveys": [
    {
    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_71_invitation_settings.js": {
      "white_list": [
      'https?://drmkc\.jrc\.ec\.europa\.eu/.*',
      'https?://ec\.europa\.eu/echo/en.*',
      'https?://ec\.europa\.eu/environment/water/flood\_risk/.*',
      'https?://ec\.europa\.eu/food/animal/diseases/adns/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/plant/plant\_health\_biosecurity/europhyt/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/plant/plant\_health\_biosecurity/europhyt/notification\_procedure/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/plant/plant\_health\_biosecurity/harmful\_organism\_outbreaks/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/safety/general\_food\_law/procedures/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/safety/international\_affairs/trade/bioterror/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/safety/rasff/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/space/copernicus/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/space/galileo/index\_en\.htm.*',
      'https?://ec\.europa\.eu/health/preparedness\_response.*',
      'https?://ec\.europa\.eu/programmes/horizon2020/en/area/security.*',
      'https?://ec\.europa\.eu/programmes/horizon2020/en/h2020\-section/climate\-action\-environment\-resource\-efficiency\-and\-raw\-materials.*',
      'https?://ec\.europa\.eu/regional\_policy/en/funding/solidarity\-fund/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/themes/climate\-change/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/what/glossary/e/eu\-solidarity\-fund.*',
      'https?://ec\.europa\.eu/europeaid/policies/fragility\-and\-crisis\-management\_en.*',
      'https?://ec\.europa\.eu/europeaid/sectors/environment/climate\-change\-disaster\-risk\-reduction\-and\-desertification\_en.*',
      'https?://ec\.europa\.eu/jrc/en/research\-topic/energy\-system\-and\-security\-supply.*'

      
      ], 
      "black_list": [
      ]
    }
  },
  {
    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_69_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/environment/integration/energy/uff\_context\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/raw\-materials/index\_en\.htm.*',
      'https?://ec\.europa\.eu/programmes/horizon2020/en/area/raw\-materials.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/themes/low\-carbon\-economy/.*',
      'https?://ec\.europa\.eu/europeaid/sectors/energy\-0\_en.*',
      'https?://ec\.europa\.eu/growth/tools\-databases/eip\-raw\-materials/.*',
      'https?://ec\.europa\.eu/growth/tools\-databases/minventory/.*',
      'https?://ec\.europa\.eu/jrc/en.*'
      
      ], 
      "black_list": [
      ]
    }
  },
    {
    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_63_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/enlargement/.*',
      'https?://ec\.europa\.eu/environment/enlarg/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/safety/international\_affairs/enlargement/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/industry/international\-aspects/enlarging\-eu/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/single\-market/public\-procurement/international/european\-neighborhood\-policy/index\_en\.htm.*',
      'https?://ec\.europa\.eu/justice/international\-relations/enlargement/index\_en\.htm.*',
      'https?://ec\.europa\.eu/regional\_policy/en/funding/ipa/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/themes/enlargment/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/what/glossary/a/accession\-negotiations.*',
      'https?://ec\.europa\.eu/taxation\_customs/common/international\_affairs/enlargement/index\_en\.htm.*',
      'https?://ec\.europa\.eu/jrc/en/working\-with\-us/enlargement\-and\-integration.*'
      
      ], 
      "black_list": [
      ]
    }
  },
  {

    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_68_invitation_settings.js": {
      "white_list": [
      'https?://eacea\.ec\.europa\.eu/about\-eacea/legal\-remedies\-0\_en.*',
      'https?://ec\.europa\.eu/anti\-fraud/olaf\-and\-you/complaints\-olaf\-investigations\_en.*',
      'https?://ec\.europa\.eu/environment/basics/benefits\-law/eu\-environment\-law/index\_en\.htm.*',
      'https?://ec\.europa\.eu/environment/legal/law/index\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/gambling/infringements\-court\-cases/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/single\-market/public\-procurement/infringements/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/single\-market/services/infringements/index\_en\.htm.*',
      'https?://ec\.europa\.eu/justice/citizen/complaints/index\_en\.htm.*',
      'https?://ec\.europa\.eu/regional\_policy/en/contact/.*',
      'https?://ec\.europa\.eu/research/index\.cfm\?lg=en&pg=enquiries.*',
      'https?://ec\.europa\.eu/research/index\.cfm\?pg=faqandenquiries&lg=en.*',
      'https?://ec\.europa\.eu/research/index\.cfm\?pg=feedback.*',
      'https?://ec\.europa\.eu/research/participants/docs/h2020\-funding\-guide/grants/applying\-for\-funding/submit\-proposals/submission\-tool\_en\.htm.*',
      'https?://ec\.europa\.eu/taxation\_customs/common/contact/index\_en\.htm.*',
      'https?://ec\.europa\.eu/europeaid/funding/about\-funding\-and\-procedures/legal\-affairs\_en.*',
      'https?://ec\.europa\.eu/programmes/horizon2020/contact.*'
      
      ], 
      "black_list": [
      ]
    }
  },
  {

    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_65_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/environment/aarhus/index\.htm.*',
      'https?://ec\.europa\.eu/justice/civil/index\_en\.htm.*',
      'https?://ec\.europa\.eu/justice/criminal/judicial\-cooperation/index\_en\.htm.*',
      'https?://ec\.europa\.eu/anti\-fraud/investigations/partners\_en.*'
      
      ], 
      "black_list": [
      ]
    }
  },
  {

    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_57_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/growth/sectors/defence/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/space/copernicus/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/space/galileo/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/space/security/index\_en\.htm.*',
      'https?://ec\.europa\.eu/health/preparedness\_response/.*',
      'https?://ec\.europa\.eu/maritimeaffairs/policy/maritime\-security/index\_en\.htm.*',
      'https?://ec\.europa\.eu/taxation\_customs/customs/customs\_controls/cash\_controls/index\_en\.htm.*',
      'https?://ec\.europa\.eu/taxation\_customs/customs/policy\_issues/customs\_strategy/index\_en\.htm.*',
      'https?://ec\.europa\.eu/jrc/en/research\-topic/crisis\-management.*',
      'https?://ec\.europa\.eu/jrc/en/research\-topic/critical\-infrastructure\-protection.*'
      
      ], 
      "black_list": [
      ]
    }
  },
  {

    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_56_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/anti\-fraud/home\_en.*',
      'https?://ec\.europa\.eu/dgs/home\-affairs/financing/fundings/research\-for\-security/index\_en\.htm.*',
      'https?://ec\.europa\.eu/environment/legal/crime/index\.htm.*',
      'https?://ec\.europa\.eu/food/safety/official\_controls/food\_fraud/index\_en\.htm.*',
      'https?://ec\.europa\.eu/justice/civil/financial\-crime/index\_en\.htm.*',
      'https?://ec\.europa\.eu/justice/criminal/index\_en\.htm.*',
      'https?://ec\.europa\.eu/programmes/horizon2020/en/area/security.*',
      'https?://ec\.europa\.eu/programmes/horizon2020/en/h2020\-section/secure\-societies\-%E2%80%93\-protecting\-freedom\-and\-security\-europe\-and\-its\-citizens.*',
      'https?://ec\.europa\.eu/regional\_policy/en/conferences/anticorruption/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/how/improving\-investment/integrity\-pacts/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/themes/better\-public\-administration/.*',
      'https?://ec\.europa\.eu/taxation\_customs/taxation/tax\_cooperation/index\_en\.htm.*',
      'https?://ec\.europa\.eu/taxation\_customs/taxation/tax\_fraud\_evasion/index\_en\.htm.*',
      'https?://ec\.europa\.eu/jrc/en/research\-topic/antifraud.*'
      
      ], 
      "black_list": [
      ]
    }
  },
  {

    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_53_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/environment/funding/intro\_en\.htm.*',
      'https?://ec\.europa\.eu/environment/life.*',
      'https?://ec\.europa\.eu/regional\_policy/en/atlas/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/funding/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/newsroom/funding\-opportunities/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/how/improving\-investment/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/how/stages\-step\-by\-step/strategic\-report/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/what/glossary/b/budget.*',
      'https?://ec\.europa\.eu/regional\_policy/en/projects/.*'
      
      ], 
      "black_list": [
      ]
    }
  },
  {

    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_49_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/internal\_market/imi\-net/data\_protection/index\_en\.htm.*',
      'https?://ec\.europa\.eu/jrc/en/privacy\-statement.*',
      'https?://ec\.europa\.eu/justice/data\-protection/index\_en\.htm.*',
      'https?://ec\.europa\.eu/anti\-fraud/policy/international\-cooperation\_en.*',
      'https?://ec\.europa\.eu/anti\-fraud/olaf\-and\-you/data\-protection\_en.*',
      'https?://ec\.europa\.eu/anti\-fraud/investigations\_en.*'
    
      ], 
      "black_list": [
      ]
    }
  },
  {

    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_36_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/clima/policies/international/cooperation/china/index\_en\.htm.*',
      'https?://ec\.europa\.eu/clima/policies/international/cooperation/index\_en\.htm.*',
      'https?://ec\.europa\.eu/clima/policies/international/cooperation/india/index\_en\.htm.*',
      'https?://ec\.europa\.eu/clima/policies/international/cooperation/south\-africa/index\_en\.htm.*',
      'https?://ec\.europa\.eu/clima/policies/international/finance/index\_en\.htm.*',
      'https?://ec\.europa\.eu/clima/policies/international/finance/transparency/index\_en\.htm.*',
      'https?://ec\.europa\.eu/clima/policies/international/index\_en\.htm.*',
      'https?://ec\.europa\.eu/clima/policies/international/negotiations/index\_en\.htm.*',
      'https?://ec\.europa\.eu/clima/policies/international/negotiations/initiatives/index\_en\.htm.*',
      'https?://ec\.europa\.eu/clima/policies/international/negotiations/paris/index\_en\.htm.*',
      'https?://ec\.europa\.eu/clima/policies/international/negotiations/progress/index\_en\.htm.*',
      'https?://ec\.europa\.eu/dgs/health\_food\-safety/amr/action\_global/index\_en\.htm.*',
      'https?://ec\.europa\.eu/echo/partnerships/relations\_en.*',
      'https?://ec\.europa\.eu/enlargement/.*',
      'https?://ec\.europa\.eu/environment/basics/global\-challenges/index\_en\.htm.*',
      'https?://ec\.europa\.eu/environment/international\_issues/index\_en\.htm.*',
      'https?://ec\.europa\.eu/fisheries/cfp/international/agreements/index\_en\.htm.*',
      'https?://ec\.europa\.eu/fisheries/cfp/international/index\_en\.htm.*',
      'https?://ec\.europa\.eu/fisheries/cfp/international/international\_agreements/index\_en\.htm.*',
      'https?://ec\.europa\.eu/fisheries/cfp/international/rfmo/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/animal/animalproducts/personal\_imports/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/animals/pet\-movement/eu\-legislation/non\-commercial\-non\-eu/tpe\_en\.htm.*',
      'https?://ec\.europa\.eu/food/animals/welfare/international/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/animals/zootechnics/third\_countries/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/plant/gmo/international\_affairs/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/safety/international\_affairs/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/safety/official\_controls/legislation/imports/approval/index\_en\.htm.*',
      'https?://ec\.europa\.eu/food/safety/official\_controls/legislation/imports/non\-animal/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/industry/international\-aspects/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/cosmetics/international/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/fashion/textiles\-clothing/international\-trade/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/food/processed\-agricultural\-products/trade\-agreements/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/postal\-services/international\-activities/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/raw\-materials/specific\-interest/international\-aspects/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/space/international\-aspects/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/tourism/international\-cooperation/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/single\-market/european\-standards/policy/international\-activities/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/single\-market/public\-procurement/international/bilateral\-non\-eu/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/single\-market/public\-procurement/international/index\_en\.htm.*',
      'https?://ec\.europa\.eu/health/eu\_world/.*',
      'https?://ec\.europa\.eu/justice/international\-relations/index\_en\.htm.*',
      'https?://ec\.europa\.eu/maritimeaffairs/policy/ocean\-governance/index\_en\.htm.*',
      'https?://ec\.europa\.eu/regional\_policy/en/atlas/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/funding/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/funding/ipa/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/newsroom/funding\-opportunities/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/cooperation/international/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/how/improving\-investment/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/how/stages\-step\-by\-step/strategic\-report/.*',
      'https?://ec\.europa\.eu/regional\_policy/en/policy/what/glossary/b/budget.*',
      'https?://ec\.europa\.eu/regional\_policy/en/projects/.*',
      'https?://ec\.europa\.eu/research/iscp/index\.cfm.*',
      'https?://ec\.europa\.eu/taxation\_customs/common/international\_affairs/index\_en\.htm.*',
      'https?://ec\.europa\.eu/taxation\_customs/customs/policy\_issues/customs\_security/aeo/mutual\_recognition\_agreement/index\_en\.htm.*',
      'https?://ec\.europa\.eu/taxation\_customs/taxation/tax\_fraud\_evasion/acting\_globally/index\_en\.htm.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/agreements/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/australia/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/azerbaijan/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/bangladesh.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/belarus/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/brazil/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/cambodia/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/canada/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/chile/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/china/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/egypt/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/georgia/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/hong\-kong\-sar/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/iceland/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/india/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/indonesia/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/iran/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/iraq/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/israel/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/japan/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/jordan/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/kazakhstan/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/laos/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/lebanon/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/libya/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/malaysia/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/mexico/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/moldova/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/morocco/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/myanmar/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/new\-zealand/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/norway/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/pakistan/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/palestine/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/paraguay/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/philippines/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/russia/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/singapore/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/south\-africa/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/south\-korea/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/sri\-lanka/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/switzerland/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/syria/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/taiwan/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/thailand/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/tunisia/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/turkey/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/ukraine/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/united\-states/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/uruguay/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/venezuela/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/countries/vietnam/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/development/aid\-for\-trade/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/development/economic\-partnerships/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/development/generalised\-scheme\-of\-preferences/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/regions/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/regions/africa\-caribbean\-pacific/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/regions/andean\-community/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/regions/asean/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/regions/central\-america/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/regions/central\-asia/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/regions/euro\-mediterranean\-partnership/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/regions/gulf\-region/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/regions/mercosur/.*',
      'https?://ec\.europa\.eu/trade/policy/countries\-and\-regions/regions/western\-balkans/.*',
      'https?://ec\.europa\.eu/trade/policy/eu\-and\-wto/.*',
      'https?://ec\.europa\.eu/trade/policy/eu\-position\-in\-world\-trade/.*',
      'https?://exporthelp\.europa\.eu.*',
      'https?://ec\.europa\.eu/europeaid/about\-funding\_en.*',
      'https?://ec\.europa\.eu/europeaid/countries\-territories\-and\-regions\-where\-we\-are\-active\_en.*',
      'https?://ec\.europa\.eu/europeaid/funding/procedures\-beneficiary\-countries\-and\-other\-donors\_en.*',
      'https?://ec\.europa\.eu/europeaid/home\_en.*',
      'https?://ec\.europa\.eu/europeaid/multimedia/publications\_en.*',
      'https?://ec\.europa\.eu/europeaid/news\-events\_en.*',
      'https?://ec\.europa\.eu/europeaid/policies/international\-development\-dialogue\_en.*',
      'https?://ec\.europa\.eu/europeaid/policies/policies\_en.*',
      'https?://ec\.europa\.eu/europeaid/projects\-results\_en.*',
      'https?://ec\.europa\.eu/europeaid/sectors/sectors\_en.*',
      'https?://ec\.europa\.eu/jrc/en/working\-with\-us.*',
      'https?://ec\.europa\.eu/programmes/horizon2020/en/area/international\-cooperation.*'

      ], 
      "black_list": [
      ]
    }
  },
  {

    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/04/task_19_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/environment/basics/benefits\-law/right2know/index\_en.htm.*',
      'https?://ec\.europa\.eu/environment/basics/knowledge/information\-policies/index\_en.htm.*'

      ], 
      "black_list": [
      ]
    }
  },
  {
    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/03/task_19_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/clima/#test_survey',
      'https?://publications\.jrc\.ec\.europa\.eu/repository/.*',
      'https?://data\.jrc\.ec\.europa\.eu/.*',
      'https?://ec\.europa\.eu/jrc/en.*',
      'https?://ec\.europa\.eu/justice/contact/index\_en\.htm.*',
      'https?://ec\.europa\.eu/enlargement/news\_corner/iati/index\_en\.htm.*',
      'https?://ec\.europa\.eu/research/consultations/list\_en\.cfm.*'

      ], 
      "black_list": [
      ]
    }
  },
  {
    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/03/task_31_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/dgs/translation/programmes/emt.*',
      'https?://ec\.europa\.eu/growth/single\-market/services/free\-movement\-professionals/index_en\.htm.*',
      'https?://ec\.europa\.eu/growth/single\-market/services/free\-movement\-professionals/qualifications\-recognition/experience/index_en\.htm.*',
      'https?://ec\.europa\.eu/growth/tools\-databases/regprof/.*',
      'https?://ec\.europa\.eu/growth/sectors/construction/apprenticeships/index_en\.htm.*',
      'https?://europa\.eu/youreurope/citizens/work/professional\-qualifications/index_en\.htm.*',
      'https?://europa\.eu/youreurope/citizens/work/professional\-qualifications/regulated\-professions/index_en\.htm.*',
      'https?://europa\.eu/youreurope/citizens/work/professional\-qualifications/recognition\-of\-professional\-qualifications/index_en\.htm.*',
      'https?://europa\.eu/youreurope/citizens/work/professional\-qualifications/european\-professional\-card/index_en\.htm.*',
      'https?://europa\.eu/youreurope/citizens/education/university/recognition/index_en\.htm.*',
      'https?://ec\.europa\.eu/health/workforce/.*',
      'https?://ec\.europa\.eu/jrc/en/research\-topic/employability\-and\-social\-inclusion.*',
      'https?://ec\.europa\.eu/jrc/en/research\-topic/learning\-and\-skills.*'

      ], 
      "black_list": [
      ]
    }
  },
  {
    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/03/task_37_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/dgs/translation.*',
      'https?://ec\.europa\.eu/translation.*',
      'https?://www\.ec\.europa\.eu/eurydice.*'

      ], 
      "black_list": [
      ]
    }
  },
  {
    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/03/task_53_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/budget/.*',
      'https?://ec\.europa\.eu/clima/.*',
      'https?://ec\.europa\.eu/europeaid/news\-events\_en.*',
      'https?://ec\.europa\.eu/europeaid/sectors/human\-rights\-and\-governance/peace\-and\-security\_en.*',
      'https?://ec\.europa\.eu/justice/contracts/index\_en\.htm.*',
      'https?://ec\.europa\.eu/justice/grants1/open\-calls/index\_en\.htm.*',
      'https?://ec\.europa\.eu/enlargement/instruments/* .*',
      'https?://ec\.europa\.eu/enlargement/tenders/*.*',
      'https?://ec\.europa\.eu/health/health\_structural\_funds/.*',
      'https?://ec\.europa\.eu/health/investment\_plan/.*',
      'https?://ec\.europa\.eu/health/programme.*',
      'https?://ec\.europa\.eu/dgs/health\_food\-safety/funding/cff/index\_en\.htm.*',
      'https?://ec\.europa\.eu/research/participants/docs/h2020\-funding\-guide/grants/applying\-for\-funding/find\-a\-call/h2020\-structure\-and\-budget\_en\.htm.*',
      'https?://ec\.europa\.eu/echo/funding\-evaluations/funding\-humanitarian\-aid\_en.*',
      'https?://ec\.europa\.eu/echo/funding\-evaluations/financing\-civil\-protection\_en.*',
      'https?://ec\.europa\.eu/echo/funding\-evaluations/public\-procurement\_en.*',
      'https?://ec\.europa\.eu/echo/funding\-evaluations/funding\-emergency\-support\_en.*'

      ], 
      "black_list": [
      ]
    }
  },
  {
    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/03/task_65_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/justice/civil/index_en\.htm.*',
      'https?://ec\.europa\.eu/justice/criminal/index_en\.htm.*'
      ], 
      "black_list": [
      ]
    }
  },
  {
    "https://ec.europa.eu/wel/surveys/wr_survey03/data/invitation_settings/digital_transformation/03/task_68_invitation_settings.js": {
      "white_list": [
      'https?://ec\.europa\.eu/europeaid/funding/about-funding-and-procedures/legal-affairs\_en.*',
      'https?://eacea\.ec\.europa\.eu/about-eacea/legal-remedies-0\_en.*',
      'https?://ec\.europa\.eu/growth/single-market/services/infringements/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/sectors/gambling/infringements-court-cases/index\_en\.htm.*',
      'https?://ec\.europa\.eu/growth/single-market/public-procurement/infringements/index\_en\.htm.*',
      'https?://ec\.europa\.eu/justice/citizen/complaints/index\_en\.htm.*',
      'https?://ec\.europa\.eu/taxation\_customs/common/contact/index\_en\.htm.*',
      'https?://ec\.europa\.eu/research/index\.cfm\?pg=faqandenquiries&lg=en.*',
      'https?://ec\.europa\.eu/research/index\.cfm\?pg=feedback.*',
      'https?://ec\.europa\.eu/programmes/horizon2020/contact.*',
      'https?://ec\.europa\.eu/research/participants/docs/h2020-funding-guide/grants/applying-for-funding/submit-proposals/submission-tool\_en\.htm.*',
      'https?://ec\.europa\.eu/research/index\.cfm\?lg=en&pg=enquiries.*'
      ], 
      "black_list": [
      ]
    }
  },
  ]
});